@@ -5,7 +5,7 @@ import dacy  # noqa
 
 def test_add_hate_speech_detection():
     nlp = spacy.blank("da")
-    nlp.add_pipe("dacy.hatespeech_detection")
+    nlp.add_pipe("dacy/hatespeech_detection")
     texts = ["senile gamle idiot", "hej har du haft en god dag"]
     actual = ["offensive", "not offensive"]
     docs = list(nlp.pipe(texts))
@@ -18,7 +18,7 @@ def test_add_hate_speech_detection():
 
 def test_add_bertemotion_emo():
     nlp = spacy.blank("da")
-    nlp.add_pipe("dacy.hatespeech_detection")
-    nlp.add_pipe("dacy.hatespeech_classification")
+    nlp.add_pipe("dacy/hatespeech_detection")
+    nlp.add_pipe("dacy/hatespeech_classification")
     doc = nlp("senile gamle idiot")
     assert doc._.hate_speech_type == "sprogbrug"
